@@ -6,6 +6,8 @@ library(corporaexplorer)
 
 abc <- test_data
 
+## corporaexplorer::test_data does not need this step,
+    # but it tests that new corporaexplorerobjects do not encounter errors here:
 source("./global/backwards_compatibility.R", local = TRUE)
 
 DATE_BASED_CORPUS <- abc$date_based_corpus
@@ -22,7 +24,7 @@ GROUPING_VARIABLE <-
 
 INFO_COLUMNS <- abc$columns_for_info
 abc <- abc$original_data$data_dok
-abc$Text <- abc$Text_original_case
+abc$Text_column_ <- abc$Text_original_case
 
 my_colours <-
   rep(c("red", "blue", "green", "purple", "orange", "gray"), 10)
